@@ -6,9 +6,10 @@ use warnings;
 use WWW::Shopify;
 
 package WWW::Shopify::Model::Address;
-use parent "WWW::Shopify::Model::Item";
+use parent "WWW::Shopify::Model::NestedItem";
 
-sub stats($) { return {
+my $fields; sub fields { return $fields; } 
+BEGIN { $fields = {
 	"address1" => new WWW::Shopify::Field::String::Address(),
 	"address2" => new WWW::Shopify::Field::String::Address(),
 	"city" => new WWW::Shopify::Field::String::City(),
@@ -23,10 +24,12 @@ sub stats($) { return {
 	"zip" => new WWW::Shopify::Field::String("[A-Z][0-9][A-Z] [0-9][A-Z][0-9]"),
 	"name" => new WWW::Shopify::Field::String::Words(1, 3),
 	"country_code" => new WWW::Shopify::Field::String("[A-Z]{3}"),
-	"province_code" => new WWW::Shopify::Field::String("[A-Z]{2}")};
-}
-sub plural() { return 'addresses'; }
+	"province_code" => new WWW::Shopify::Field::String("[A-Z]{2}"),
+	"id" => new WWW::Shopify::Field::Identifier()
+}; }
+sub plural { return 'addresses'; }
+sub parent { return undef; }
 
-eval(WWW::Shopify::Model::Item::generate_accessors(__PACKAGE__)); die $@ if $@;
+eval(__PACKAGE__->generate_accessors); die $@ if $@;
 
 1;
