@@ -11,7 +11,7 @@ use parent "WWW::Shopify::Model::Item";
 my $fields; sub fields { return $fields; } 
 BEGIN { $fields = {
 	"product_id" => new WWW::Shopify::Field::Relation::ReferenceOne("WWW::Shopify::Model::Product"),
-	"collection_id" => new WWW::Shopify::Field::Relation::Parent("WWW::Shopify::Model::CustomCollection"),
+	"collection_id" => new WWW::Shopify::Field::Relation::ReferenceOne("WWW::Shopify::Model::CustomCollection"),
 	"created_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00', max => 'now'),
 	"updated_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00', max => 'now'),
 	"featured" => new WWW::Shopify::Field::Boolean(),
@@ -20,13 +20,11 @@ BEGIN { $fields = {
 	"sort_value" => new WWW::Shopify::Field::Int(),
 }; }
 
-sub parent { return "WWW::Shopify::Model::CustomCollection"; }
 
-sub get_all_through_parent { return undef; }
-sub get_through_parent { return undef; }
-sub create_through_parent { return undef; }
-sub update_through_parent { return undef; } 
-sub delete_through_parent { return undef; }
+my $queries; sub queries { return $queries; }
+BEGIN { $queries = {
+	collection_id => new WWW::Shopify::Query::Match('collection_id')
+}; }
 
 sub creation_minimal { return qw(product_id collection_id); }
 sub creation_filled { return qw(position created_at); }
