@@ -8,11 +8,14 @@ use WWW::Shopify;
 package WWW::Shopify::Model::Order::Fulfillment::Receipt;
 use parent "WWW::Shopify::Model::NestedItem";
 
-sub stats($) { return {
+my $fields; sub fields { return $fields; } 
+BEGIN { $fields = {
 	"testcase" => new WWW::Shopify::Field::Boolean(),
 	"authorization" => new WWW::Shopify::Field::String("[0-9]{5,10}")};
 }
+sub creation_minimal { return qw(title); }
+sub creation_filled { return qw(id); }
 
-eval(WWW::Shopify::Model::Item::generate_accessors(__PACKAGE__)); die $@ if $@;
+eval(__PACKAGE__->generate_accessors); die $@ if $@;
 
 1;
