@@ -15,8 +15,8 @@ sub singular { return "smart_collection"; }
 my $fields; sub fields { return $fields; } 
 BEGIN { $fields = {
 	"body_html" => new WWW::Shopify::Field::Text::HTML(),
-	"handle" => new WWW::Shopify::Field::String("[a-z]{2,8}-[a-z]{2,8}"),
-	"sort_order" => new WWW::Shopify::Field::String("(manual|automatic)"),
+	"handle" => new WWW::Shopify::Field::String::Handle(),
+	"sort_order" => new WWW::Shopify::Field::String::Enum(["manual", "automatic"]),
 	"template_suffix" => new WWW::Shopify::Field::String(),
 	"title" => new WWW::Shopify::Field::String::Words(1, 2),
 	"rules" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::SmartCollection::Rule"),
@@ -24,7 +24,8 @@ BEGIN { $fields = {
 	"id" => new WWW::Shopify::Field::Identifier(),
 	"created_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00', max => 'now'),
 	"updated_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00', max => 'now'),
-	"published_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00', max => 'now')
+	"published_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00', max => 'now'),
+	"published_scope" => new WWW::Shopify::Field::String()
 }; }
 
 sub creation_minimal { return qw(topic address); }
